(* Programa para calcular as Amplitudes de Helicidade para o 
   efeito de Compton com fermioes com massa. Eqs 6.56 and 6.57 of QFT

 Last Version: 08/12/2024
 Compatible with FC 9.3 and 10.1.0
 Author: Jorge C. Romao
 email: jorge.romao@tecnico.ulisboa.pt

*)

Remove["Global`*"]

(* Definitions *)
SetOptions[DiracSimplify,DiracSubstitute67->False]

dp=Function[s,If[s==1,GA[6],If[s==-1,GA[7]]]]
  
U[p_,s_]:= dp[s] . SpinorU[p,0]

UBar[p_,s_]:=  SpinorUBar[p,0] . dp[-s]

PolSConjU = 
  Function[{k, p, l, i}, 
   If[i == 1, 2 U[k, l], If[i == 2, 2 U[p, -l]]]];
PolSConjUBar = 
  Function[{k, p, l, i}, 
   If[i == 1, UBar[p, l], If[i == 2, UBar[k, -l]]]];
PolSU = Function[{k, p, l, i}, 
   If[i == 1, 2 U[p, l], If[i == 2, 2 U[k, -l]]]];
PolSUBar = 
  Function[{k, p, l, i}, 
   If[i == 1, UBar[k, l], If[i == 2, UBar[p, -l]]]];
MydsU = Function[{p, i}, If[i == 1, U[p, 1], If[i == 2, U[p, -1]]]];
MydsUBar = 
  Function[{p, i}, If[i == 1, UBar[p, 1], If[i == 2, UBar[p, -1]]]];


  
(* Fermions with masss *)

Um[p1_,p2_,m_,s_]:=(If[s==1,sp[p1,p2],spc[p2,p1]]/m U[p1,s] + U[p2,-s])
Vm[p1_,p2_,m_,s_]:=(If[s==1,sp[p1,p2],spc[p2,p1]]/m U[p1,s] - U[p2,-s])

UmBar[p1_,p2_,m_,s_]:=(If[s==1,spc[p1,p2],sp[p2,p1]]/m UBar[p1,s] 
		       + UBar[p2,-s])
VmBar[p1_,p2_,m_,s_]:=(If[s==1,spc[p1,p2],sp[p2,p1]]/m UBar[p1,s] 
		       - UBar[p2,-s])

(* Amplitudes *)


MDiag1[s1_, s2_, l1_, l2_] := 
  Sum[(UmBar[w1, w2, m, s2].PolSConjU[k2, r1, l2, i1])*
  (PolSConjUBar[k2,r1, l2, i1].MydsU[r1, i2]) *
      (MydsUBar[r1, i2] .PolSU[k1, r1, l1, i3]) *
      (PolSUBar[k1, r1, l1, i3].Um[r1, r2, m, s1]) +
      (UmBar[w1, w2, m, s2].PolSConjU[k2, r1, l2, i1]) *
      (PolSConjUBar[k2, r1, l2, i1].MydsU[r2, i2]) *
      (MydsUBar[r2, i2] .PolSU[k1, r1, l1, i3]) *
      (PolSUBar[k1, r1, l1, i3].Um[r1, r2, m, s1]) +
      (UmBar[w1, w2, m, s2].PolSConjU[k2, r1, l2, i1]) *
      (PolSConjUBar[k2, r1, l2, i1].MydsU[k1, i2]) *
      (MydsUBar[k1, i2] .PolSU[k1, r1, l1, i3]) *
      (PolSUBar[k1, r1, l1, i3].Um[r1, r2, m, s1]),
      {i1, 1, 2}, {i2, 1, 2}, {i3, 1, 2}] +
      m (Sum[(UmBar[w1, w2, m, s2].PolSConjU[k2, r1, l2, i1]) *
      (PolSConjUBar[k2, r1, l2, i1].PolSU[k1, r1, l1, i2]) *
      (PolSUBar[k1, r1, l1, i2].Um[r1, r2, m, s1]), {i1, 1, 2}, {i2, 1, 1}]);


MDiag2[s1_, s2_, l1_, l2_] := 
  Sum[(UmBar[w1, w2, m, s2].PolSU[k1, r1, l1, i1]) *
      (PolSUBar[k1, r1, l1, i1].MydsU[r1, i2]) *
      (MydsUBar[r1, i2] .PolSConjU[k2, r1, l2, i3]) *
      (PolSConjUBar[k2, r1, l2, i3].Um[r1, r2, m, s1]) +
      (UmBar[w1, w2, m, s2].PolSU[k1, r1, l1, i1]) *
      (PolSUBar[k1, r1, l1, i1].MydsU[r2, i2]) *
      (MydsUBar[r2, i2] .PolSConjU[k2, r1, l2, i3]) *
      (PolSConjUBar[k2, r1, l2, i3].Um[r1, r2, m, s1]) - 
      (UmBar[w1, w2, m, s2].PolSU[k1, r1, l1, i1]) *
      (PolSUBar[k1, r1, l1, i1].MydsU[k2, i2]) *
      (MydsUBar[k2, i2] .PolSConjU[k2, r1, l2, i3]) *
      (PolSConjUBar[k2, r1, l2, i3].Um[r1, r2, m, s1]),
      {i1, 1, 2}, {i2, 1, 2}, {i3, 1, 2}] +
      m (Sum[(UmBar[w1, w2, m, s2].PolSU[k1, r1, l1, i1]) *
      (PolSUBar[k1, r1, l1, i1].PolSConjU[k2, r1, l2, i2]) *
      (PolSConjUBar[k2, r1, l2, i2].Um[r1, r2, m, s1]),
	     {i1, 1, 2}, {i2, 1, 2}]);

 
res1[s1_,s2_,l1_,l2_]:=DiracSimplify[DotSimplify[MDiag1[s1,s2,l1,l2]]]
res2[s1_,s2_,l1_,l2_]:=DiracSimplify[DotSimplify[MDiag2[s1,s2,l1,l2]]]

vlist={w1,w2,k1,k2,r1,r2}


simp1=Table[SpinorU[vlist[[i]],0] . GA[7]. SpinorU[vlist[[j]],0] -> sp[vlist[[i]],vlist[[j]]],{i,1,6},{j,1,6}] /. {sp[p_, p_] -> 0}

simp2=Table[SpinorU[vlist[[i]],0] . GA[6] . SpinorU[vlist[[j]],0] -> spc[vlist[[j]],vlist[[i]]],{i,1,6},{j,1,6}] /. {spc[q_, q_] -> 0}


simp=Flatten[{simp1,simp2}]//FCI;


M1aux[s1_,s2_,l1_,l2_]:=Expand[res1[s1,s2,l1,l2] /. simp]
M2aux[s1_,s2_,l1_,l2_]:=Expand[res2[s1,s2,l1,l2] /. simp]

M1[s1_,s2_,l1_,l2_]:=Expand[M1aux[s1,s2,l1,l2]] 

M2[s1_,s2_,l1_,l2_]:=Expand[M2aux[s1,s2,l1,l2]]


(* Change to True to write OutputFortran *)

If[False,

M={C1 M1[1,1,1,1] + C2 M2[1,1,1,1], \
C1 M1[1,1,1,-1] + C2 M2[1,1,1,-1], \
C1 M1[1,1,-1,1] + C2 M2[1,1,-1,1],\
C1 M1[1,1,-1,-1] + C2 M2[1,1,-1,-1], \
C1 M1[1,-1,1,1] + C2 M2[1,-1,1,1], \
C1 M1[1,-1,1,-1] + C2 M2[1,-1,1,-1], \
C1 M1[1,-1,-1,1] + C2 M2[1,-1,-1,1], \
C1 M1[1,-1,-1,-1] + C2 M2[1,-1,-1,-1], \
C1 M1[-1,1,1,1] + C2 M2[-1,1,1,1], \
C1 M1[-1,1,1,-1] + C2 M2[-1,1,1,-1], \
C1 M1[-1,1,-1,1] + C2 M2[-1,1,-1,1], \
C1 M1[-1,1,-1,-1] + C2 M2[-1,1,-1,-1], \
C1 M1[-1,-1,1,1] + C2 M2[-1,-1,1,1], \
C1 M1[-1,-1,1,-1] + C2 M2[-1,-1,1,-1], \
C1 M1[-1,-1,-1,1] + C2 M2[-1,-1,-1,1], \
C1 M1[-1,-1,-1,-1] + C2 M2[-1,-1,-1,-1]};


stmp=OpenWrite["ComptonAmplitudes.f",FormatType -> FortranForm,PageWidth -> 60];
Do[Write[stmp,"HelAmp(",i,")=",M[[i]]],{i,1,16}];
Close[stmp];

]
