(* Program to Calculate the Helicity Amplitudes in Eq. (6.33) of QFT 

 Compatible with FC 9.3 and 10.1.0
 
 Last Version: 08/12/2024
 Author: Jorge C. Romao
 email: jorge.romao@tecnico.ulisboa.pt
*)

Remove["Global`*"]

SetOptions[DiracSimplify,DiracSubstitute67->False]
  
prop[p_, m_] := GS[p] + m


(*dp[s_]:= (1 + s GA[5])/2*)

dp=Function[s,If[s==1,GA[6],If[s==-1,GA[7]]]]

U[p_,s_]:= dp[s] . SpinorU[p,0]

UBar[p_,s_]:=  SpinorUBar[p,0] . dp[-s]


(* Only for feynCalc 9.2   

Myds=Function[{p,i},If[i==1, U[p,1] UBar[p,1],If[i==2, U[p,-1] UBar[p,-1]]]] 
PolS=Function[{k,p,l,i},If[i==1,  U[p,l]  UBar[k,l],If[i==2,  2  U[k,-l]  UBar[p,-l]]]]

*)
  
(*
To be compatible with FeynCalc 9.3 we have to separate the spinor and 
spinorBar in the definitions of GS[p] and Polarization sums.

The code below works for FeynCalc 9.2 and 9.3
*)


PolSConjU=Function[{k,p,l,i}, If[i==1, 2 U[k,l],If[i==2, 2 U[p,-l]]]]

PolSConjUBar=Function[{k,p,l,i}, If[i==1,UBar[p,l],If[i==2, UBar[k,-l]]]]

MydsU=Function[{p,i},If[i==1, U[p,1],If[i==2, U[p,-1]]]] 

MydsUBar=Function[{p,i},If[i==1, UBar[p,1],If[i==2, UBar[p,-1]]]] 

M1[s1_,s2_,l1_,l2_]:=Sum[((UBar[p2,s2] . PolSConjU[k2,p2,l2,i1])*( PolSConjUBar[k2,p2,l2,i1] . MydsU[p1,i2])*(MydsUBar[p1,i2] . PolSConjU[k1,p1,l1,i3])*( PolSConjUBar[k1,p1,l1,i3] . U[p1,s1])),{i1,1,2},{i2,1,2},{i3,1,2}]-Sum[((UBar[p2,s2] . PolSConjU[k2,p2,l2,i1])*(PolSConjUBar[k2,p2,l2,i1] . MydsU[k1,i2])*(MydsUBar[k1,i2] . PolSConjU[k1,p1,l1,i3])*(PolSConjUBar[k1,p1,l1,i3] . U[p1,s1])),{i1,1,2},{i2,1,2},{i3,1,2}]

res1[s1_,s2_,l1_,l2_]:=DiracSimplify[M1[s1,s2,l1,l2]]/t/N11^2


  M2[s1_,s2_,l1_,l2_]:=Sum[(UBar[p2,s2] . PolSConjU[k1,p2,l1,i1]) (PolSConjUBar[k1,p2,l1,i1]  . MydsU[p1,i2]) (MydsUBar[p1,i2] . PolSConjU[k2,p1,l2,i3]) (PolSConjUBar[k2,p1,l2,i3] .  U[p1,s1]),{i1,1,2},{i2,1,2},{i3,1,2}] - Sum[(UBar[p2,s2] . PolSConjU[k1,p2,l1,i1]) (PolSConjUBar[k1,p2,l1,i1] . MydsU[k2,i2]) (MydsUBar[k2,i2] . PolSConjU[k2,p1,l2,i3]) (PolSConjUBar[k2,p1,l2,i3] .  U[p1,s1]),{i1,1,2},{i2,1,2},{i3,1,2}]

res2[s1_,s2_,l1_,l2_]:=DiracSimplify[M2[s1,s2,l1,l2]]/u/N12^2


(* Simplify *)

vlist={p1,p2,k1,k2}

simp1=Table[SpinorU[vlist[[i]],0] . GA[7]. SpinorU[vlist[[j]],0] -> sp[vlist[[i]],vlist[[j]]],{i,1,4},{j,1,4}] /. {sp[p_, p_] -> 0}

simp2=Table[SpinorU[vlist[[i]],0] . GA[6] . SpinorU[vlist[[j]],0] -> spc[vlist[[j]],vlist[[i]]],{i,1,4},{j,1,4}] /. {spc[q_, q_] -> 0}


simp=Flatten[{simp1,simp2}]//FCI;

sim={sp[p2,p1]->-sp[p1,p2],spc[p2,p1]->-spc[p1,p2],sp[k2,k1]->-sp[k1,k2],spc[k2,k1]->-spc[k1,k2], sp[k1,p1]->-sp[p1,k1],spc[k1,p1]->-spc[p1,k1],sp[k2,p1]->-sp[p1,k2],spc[k2,p1]->-spc[p1,k2],sp[k1,p2]->-sp[p2,k1],spc[k1,p2]->-spc[p2,k1], sp[k2,p2]->-sp[p2,k2],spc[k2,p2]->-spc[p2,k2]}

kin={sp[p1, p2]*spc[p1, p2] -> s, sp[k1, k2]*spc[k1, k2] -> s, sp[p1, k1]*spc[p1, k1] -> -t, sp[p2, k2]*spc[p2, k2] -> -t, sp[p1, k2]*spc[p1, k2] -> -u, sp[p2, k1]*spc[p2, k1] -> -u,N11->Sqrt[-2 t],N12->Sqrt[-2 u]}


norma={N11->(2 sp[p1, k1] spc[p1, k1])^(1/2),N12->(2 sp[p1, k2] spc[p1, k2])^(1/2)}

M[s1_,s2_,l1_,l2_]:=Simplify[((-e^2(res1[s1,s2,l1,l2]+res2[s1,s2,l1,l2]) /.simp) /. norma) /. sim] 
