(* Program to Calculate the traces of Moller scattering neglecting
   the electron mass. 

 Compatible with FC 9.3 and 10.1.0
 
 Last Version: 08/12/2024
 Author: Jorge C. Romao
 email: jorge.romao@tecnico.ulisboa.pt
*)


Remove["Global`*"]

(* Definitions *)

prop[p_,m_]:=GS[p]+m



Line1:= prop[p3,m] . GA[mu] .  prop[p1,m] . GA[nu]  

Line2:= prop[p4,m] . GA[mu] .  prop[p2,m] . GA[nu]

Line3:= prop[p4,m] . GA[mu] .  prop[p1,m] . GA[nu]  

Line4:= prop[p3,m] . GA[mu] .  prop[p2,m] . GA[nu]

Line5:= prop[p3,m] . GA[mu] .  prop[p1,m] . GA[nu] . prop[p4,m] . GA[mu] . prop[p2,m] . GA[nu] 



ans1= Simplify[Contract[TR[Line1] TR[Line2]]]

ans2= Simplify[Contract[TR[Line3] TR[Line4]]]

ans3= Simplify[Contract[TR[Line5]]]


ans=(ans1/t^2+ans2/u^2-2*ans3/u/t)/. m->0

ans= ans/4 //FCE


dot={SP[p1,p2]->s/2,SP[p3,p4]->s/2,SP[p1,p3]->-t/2,SP[p2,p4]->-t/2,SP[p1,p4]->-u/2,SP[p2,p3]->-u/2}

mandel={s-> -t -u}

resaux= ans /. dot

res= e^4 resaux /. mandel //Simplify

Print["\!\(\*FractionBox[\(1\), \(4\)]\) \!\(\*UnderscriptBox[\(\[Sum]\), \(spins\)]\)|M\!\(\*SuperscriptBox[\(|\), \(2\)]\) = ",res]

angles={t-> -s/2(1-Cos[\[Theta]]),u-> -s/2(1+Cos[\[Theta]])}

Eq5146=2 ((1+Cos[\[Theta]/2]^4)/Sin[\[Theta]/2]^4 +
       2/Sin[\[Theta]/2]^2/Cos[\[Theta]/2]^2 +
       (1+Sin[\[Theta]/2]^4)/Cos[\[Theta]/2]^4);

Print["Eq5.146=",Eq5146]

zero=((resaux/. angles)-Eq5146) //Simplify

Print["\!\(\*FractionBox[\(1\), \(4\)]\) \!\(\*UnderscriptBox[\(\[Sum]\), \(spins\)]\)|M\!\(\*SuperscriptBox[\(|\), \(2\)]\) - Eq. 5.146= ",zero]      
